## 0.3.0 (2021-10-28)

### Feat

- add PurgedKFold cross-validator

### Perf

- fill NaNs only when necessary

## 0.2.0 (2021-10-08)

### Feat

- add fetcher for validation data

## 0.1.2 (2021-10-07)

### Fix

- support earlier python versions

## 0.1.1 (2021-10-07)

### Refactor

- remove icons

## 0.1.0 (2021-10-07)

### Feat

- add fetcher for training data
